@@ -474,10 +474,13 @@ info_button_clicked_cb (GtkButton *button,
 
     populate_grid (self, grid, face);
 
-    dialog = gtk_dialog_new_with_buttons ("", GTK_WINDOW (self->main_window),
-                                          GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_USE_HEADER_BAR,
-                                          _("_Close"), GTK_RESPONSE_CLOSE,
-                                          NULL);
+    dialog = g_object_new (GTK_TYPE_DIALOG,
+                           "title", _("Info"),
+                           "transient-for", self->main_window,
+                           "modal", TRUE,
+                           "destroy-with-parent", TRUE,
+                           "use-header-bar", TRUE,
+                           NULL);
     gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), grid);
     g_signal_connect (dialog, "response",
                       G_CALLBACK (gtk_widget_destroy), NULL);
@@ -830,7 +833,6 @@ font_view_application_activate (GApplication *application)
 {
     FontViewApplication *self = FONT_VIEW_APPLICATION (application);
 
-    G_APPLICATION_CLASS (font_view_application_parent_class)->activate (application);
     font_view_application_do_overview (self);
 }
 
@@ -876,9 +878,6 @@ font_view_application_class_init (FontViewApplicationClass *klass)
 static GApplication *
 font_view_application_new (void)
 {
-    if (!FcInit ())
-        g_critical ("Can't initialize fontconfig library");
-
     return g_object_new (FONT_VIEW_TYPE_APPLICATION,
                          "application-id", "org.gnome.font-viewer",
                          "flags", G_APPLICATION_HANDLES_OPEN,
@@ -896,6 +895,9 @@ main (int argc,
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
     textdomain (GETTEXT_PACKAGE);
 
+    if (!FcInit ())
+        g_critical ("Can't initialize fontconfig library");
+
     app = font_view_application_new ();
     retval = g_application_run (app, argc, argv);
 
